@@ -51,7 +51,7 @@ extern char *evaluate_expr(objectptr, oparamptr, objinstptr);
 /* from elements.c: */
 
 /* element constructor functions */
-extern labelptr new_label(objinstptr, stringpart *, int, int, int);
+extern labelptr new_label(objinstptr, stringpart *, int, int, int, u_char);
 extern labelptr new_simple_label(objinstptr, char *, int, int, int);
 extern labelptr new_temporary_label(objectptr, char *, int, int);
 extern polyptr new_polygon(objinstptr, pointlist *, int);
@@ -802,9 +802,14 @@ extern xcWidget *pytoolbuttons(int *);
 /* from rcfile.c: */
 
 extern short execcommand(short, char *);
+#ifdef TCL_WRAPPER
 extern int defaultscript(void);
-extern void execscript(void);
 extern int loadrcfile(void);
+#else
+extern void defaultscript(void);
+extern void loadrcfile(void);
+#endif
+extern void execscript(void);
 #ifndef HAVE_PYTHON
 extern short readcommand(short, FILE *);
 #endif
@@ -1008,6 +1013,7 @@ extern int query_named_color(char *);
 extern caddr_t CvtStringToPixel(XrmValuePtr, int *, XrmValuePtr, XrmValuePtr);
 extern void outputpopup(xcWidget, caddr_t, caddr_t);
 extern void docommand(void);
+extern int getscreenDPI(void);
 extern int  installowncmap(void);  /* sometimes from xtgui.c */
 extern void destroypopup(xcWidget, popupstruct *, caddr_t);
 extern int xc_alloccolor(char *);
